# 2021-09-13 - Merkle Redeem for BAL rewards on Arbitrum

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This distributor has been deprecated in favor of the veBAL system.

Distributor contract for BAL rewards on Arbitrum.

## Useful Files

- [Arbitrum mainnet address](./output/arbitrum.json)
- [`MerkleRedeem` artifact](./artifact/MerkleRedeem.json)
